@@ -10,24 +10,24 @@
 #' When ed is in g/day, x it is the number of days (without units).
 #' When hotfi, hotc or warmc are in g/trip, x it is the number of trips (without units).
 #' When hotfi, hotc or warmc are in g/proced, x it is the number of proced (without units).
-#' @param ed average daily evaporative emisisons. If x has units 'lkm', the units
+#' @param ed average daily evaporative emissions. If x has units 'lkm', the units
 #' of ed must be 'g/km', other case, this are simply g/day (without units).
 #' @param hotfi average hot running losses or soak evaporative factor
 #' for vehicles with fuel injection and returnless fuel systems.
 #'  If x has units 'lkm', the units of ed must be 'g/km',
-#'  other case, this are simply g/trip or g/proced
+#'  other case, this is simply g/trip or g/proced
 #' @param hotc average running losses or soak evaporative factor for vehicles with
-#' carburator or fuel return system
+#' carburetor or fuel return system
 #' for vehicles with fuel injection and returnless fuel systems.
 #'  If x has units 'lkm', the units of ed must be 'g/km',
 #' @param warmc average cold and warm running losses or soak evaporative factor
-#' for vehicles with carburator or fuel return system
+#' for vehicles with carburetor or fuel return system
 #' for vehicles with fuel injection and returnless fuel systems.
 #'  If x has units 'lkm', the units of ed must be 'g/km',
-#' @param carb fraction of gasoline vehicles with carburator or fuel return system.
+#' @param carb fraction of gasoline vehicles with carburetor or fuel return system.
 #' @param p Fraction of trips finished with hot engine
 #' @param params Character; Add columns with information to returning data.frame
-#' @param pro_month Numeric; montly profile to distribuite annual mileage in each month.
+#' @param pro_month Numeric; monthly profile to distribute annual mileage in each month.
 #' @param verbose Logical; To show more information
 #' @return numeric vector of emission estimation in grams
 #' @seealso \code{\link{ef_evap}}
@@ -36,7 +36,7 @@
 #' EEA, EMEP. EEA air pollutant emission inventory guidebook-2009. European
 #' Environment Agency, Copenhagen, 2009
 #' @note  When veh is a "Vehicles" data.frame, emission factors are evaluated till the
-#' number of columns of veh. For instance, if the length of the emision factor is 20
+#' number of columns of veh. For instance, if the length of the emission factor is 20
 #' but the number of columns of veh is 10, the 10 first emission factors are used.
 #'
 #' @export
@@ -61,7 +61,7 @@ emis_evap <- function(veh,
     }
   }
   # Checking sf
-  if(any(class(veh) %in% "sf")){
+  if(inherits(veh, "sf")){
     if(verbose) message("converting sf to data.frame")
     veh <- sf::st_set_geometry(veh, NULL)
   }
