@@ -25,16 +25,19 @@
 #'   ecuador_td_im      \tab Top-down\tab EEA\tab  csv and.rds\cr
 #'   ecuador_td_hot      \tab Top-down\tab EEA\tab  csv and.rds\cr
 #'   ecuador_td_hot_month      \tab Top-down\tab EEA\tab  csv and.rds\cr
-#'   moves      \tab Bottom-up\tab US/EPA MOVES \tab  csv and.rds (requires MOVES >=3.0 on Windows)\cr
+#'   moves_bu      \tab Bottom-up\tab US/EPA MOVES \tab  csv and.rds (requires MOVES >=3.0 on Windows)\cr
 #'   manizales_bu      \tab Bottom-up  chemical mechanisms\tab EEA\tab  csv, csv.gz, .rds\cr
 #'   sebr_cb05co2_im  \tab Top-down SP, MG and RJ IM\tab CETESB+tunnel\tab  .rds\cr
+#'   eu_bu_chem      \tab Bottom-up  chemical mechanisms\tab EEA 2019\tab  .rds\cr
+#'   eu_bu_chem_simple \tab Bottom-up  chemical mechanisms 7 veh\tab EEA 2019\tab  .rds\cr
 #' }
 #' @param url String, with the URL to download VEIN project
 #' @note default case can be any of "brasil", "brazil", "brazil_bu", "brasil_bu", they are
 #' the same
 #' In any case, if you find any error, please, send a pull request in github.
 #'
-#' In Sao Paulo the IM programs was functioning until 2011. Since then,
+#' In Sao Paulo the IM programs was functioning until 2011.
+#'
 #' @importFrom utils download.file untar
 #' @export
 #' @examples \dontrun{
@@ -49,6 +52,7 @@ get_project <- function(directory,
   if(missing(directory)) stop("Please, add a path to a directory") #nocov start
 
   if(missing(url)){
+    # brazil ####
   if(case %in% c("brasil", "brazil", "brazil_bu", "brasil_bu")) {
     URL <- "https://raw.githubusercontent.com/atmoschem/vein/master/projects/brazil_bu.tar.gz"
     tf <- paste0(tempfile(), ".tar.gz")
@@ -57,7 +61,8 @@ get_project <- function(directory,
     utils::untar(tarfile = tf, exdir = directory)
     message("Your directory is in ", directory)
 
-  } else if(case == "moves_bu"){
+    # moves_bu ####
+  } else if(case %in% c("moves_bu", "moves")){
     URL <- "https://raw.githubusercontent.com/atmoschem/vein/master/projects/moves.tar.gz"
     tf <- paste0(tempfile(), ".tar.gz")
     utils::download.file(url = URL,
@@ -65,6 +70,7 @@ get_project <- function(directory,
     utils::untar(tarfile = tf, exdir = directory)
     message("Your directory is in ", directory)
 
+    # emislacovid ####
   } else if(case == "emislacovid"){
     URL <- "https://raw.githubusercontent.com/atmoschem/vein/master/projects/emislacovid.tar.gz"
     tf <- paste0(tempfile(), ".tar.gz")
@@ -73,6 +79,7 @@ get_project <- function(directory,
     utils::untar(tarfile = tf, exdir = directory)
     message("Your directory is in ", directory)
 
+    # brazil_bu_csvgz ####
   } else if(case %in% c("brazil_bu_csvgz")){
     URL <- "https://raw.githubusercontent.com/atmoschem/vein/master/projects/brazil_bu_csvgz.tar.gz"
     tf <- paste0(tempfile(), ".tar.gz")
@@ -81,6 +88,7 @@ get_project <- function(directory,
     utils::untar(tarfile = tf, exdir = directory)
     message("Your directory is in ", directory)
 
+    # brazil_bu_csv ####
   } else if(case %in% c("brazil_bu_csv")){
     URL <- "https://raw.githubusercontent.com/atmoschem/vein/master/projects/brazil_bu_csv.tar.gz"
     tf <- paste0(tempfile(), ".tar.gz")
@@ -89,6 +97,7 @@ get_project <- function(directory,
     utils::untar(tarfile = tf, exdir = directory)
     message("Your directory is in ", directory)
 
+    # brazil_bu_chem ####
   } else if(case %in% c("brazil_bu_cb05", "brazil_mech", "brazil_bu_chem")){
     URL <- "https://raw.githubusercontent.com/atmoschem/vein/master/projects/brazil_bu_chem.tar.gz"
     tf <- paste0(tempfile(), ".tar.gz")
@@ -97,6 +106,7 @@ get_project <- function(directory,
     utils::untar(tarfile = tf, exdir = directory)
     message("Your directory is in ", directory)
 
+    # brazil_bu_chem_im ####
   } else if(case %in% c("brazil_bu_chem_im")){
     URL <- "https://raw.githubusercontent.com/atmoschem/vein/master/projects/brazil_bu_chem_im.tar.gz"
     tf <- paste0(tempfile(), ".tar.gz")
@@ -105,6 +115,7 @@ get_project <- function(directory,
     utils::untar(tarfile = tf, exdir = directory)
     message("Your directory is in ", directory)
 
+    # manizales_bu ####
   } else if(case %in% c("manizales_bu")){
     URL <- "https://raw.githubusercontent.com/atmoschem/vein/master/projects/manizales_bu.tar.gz"
     tf <- paste0(tempfile(), ".tar.gz")
@@ -113,6 +124,7 @@ get_project <- function(directory,
     utils::untar(tarfile = tf, exdir = directory)
     message("Your directory is in ", directory)
 
+    # brazil_bu_chem_streets ####
   } else if(case %in% c("brazil_bu_chem_streets")){
     URL <- "https://raw.githubusercontent.com/atmoschem/vein/master/projects/brazil_bu_chem_streets.tar.gz"
     tf <- paste0(tempfile(), ".tar.gz")
@@ -121,6 +133,7 @@ get_project <- function(directory,
     utils::untar(tarfile = tf, exdir = directory)
     message("Your directory is in ", directory)
 
+    # brazil_bu_chem_streets_im ####
   } else if(case %in% c("brazil_bu_chem_streets_im")){
     URL <- "https://raw.githubusercontent.com/atmoschem/vein/master/projects/brazil_bu_chem_streets_im.tar.gz"
     tf <- paste0(tempfile(), ".tar.gz")
@@ -129,6 +142,7 @@ get_project <- function(directory,
     utils::untar(tarfile = tf, exdir = directory)
     message("Your directory is in ", directory)
 
+    # masp2020 ####
   } else if(case %in% c("masp2020")){
     URL <- "https://raw.githubusercontent.com/atmoschem/vein/master/projects/MASP_2020.tar.gz"
     tf <- paste0(tempfile(), ".tar.gz")
@@ -137,6 +151,7 @@ get_project <- function(directory,
     utils::untar(tarfile = tf, exdir = directory)
     message("Your directory is in ", directory)
 
+    # brazil_td_chem ####
   } else if(case %in% c("brazil_td_chem")){
     URL <- "https://raw.githubusercontent.com/atmoschem/vein/master/projects/brazil_td_chem.tar.gz"
     tf <- paste0(tempfile(), ".tar.gz")
@@ -145,6 +160,7 @@ get_project <- function(directory,
     utils::untar(tarfile = tf, exdir = directory)
     message("Your directory is in ", directory)
 
+    # brazil_td_chem_im ####
   } else if(case %in% c("brazil_td_chem_im")){
     URL <- "https://raw.githubusercontent.com/atmoschem/vein/master/projects/brazil_td_chem_im.tar.gz"
     tf <- paste0(tempfile(), ".tar.gz")
@@ -153,6 +169,7 @@ get_project <- function(directory,
     utils::untar(tarfile = tf, exdir = directory)
     message("Your directory is in ", directory)
 
+    # ecuador_td ####
   } else if(case %in% c("ecuador_td")){
     URL <- "https://raw.githubusercontent.com/atmoschem/vein/master/projects/ecuador_td.tar.gz"
     tf <- paste0(tempfile(), ".tar.gz")
@@ -161,6 +178,7 @@ get_project <- function(directory,
     utils::untar(tarfile = tf, exdir = directory)
     message("Your directory is in ", directory)
 
+    # ecuador_td_im ####
   } else if(case %in% c("ecuador_td_im")){
     URL <- "https://raw.githubusercontent.com/atmoschem/vein/master/projects/ecuador_td_im.tar.gz"
     tf <- paste0(tempfile(), ".tar.gz")
@@ -169,6 +187,7 @@ get_project <- function(directory,
     utils::untar(tarfile = tf, exdir = directory)
     message("Your directory is in ", directory)
 
+    # ecuador_td_hot ####
   } else if(case %in% c("ecuador_td_hot")){
     URL <- "https://raw.githubusercontent.com/atmoschem/vein/master/projects/ecuador_td_hot.tar.gz"
     tf <- paste0(tempfile(), ".tar.gz")
@@ -177,6 +196,7 @@ get_project <- function(directory,
     utils::untar(tarfile = tf, exdir = directory)
     message("Your directory is in ", directory)
 
+    # ecuador_td_hot_month ####
   } else if(case %in% c("ecuador_td_hot_month")){
     URL <- "https://raw.githubusercontent.com/atmoschem/vein/master/projects/ecuador_td_hot_month.tar.gz"
     tf <- paste0(tempfile(), ".tar.gz")
@@ -185,6 +205,7 @@ get_project <- function(directory,
     utils::untar(tarfile = tf, exdir = directory)
     message("Your directory is in ", directory)
 
+    # amazon2014 ####
   } else if(case %in% c("amazon2014")){
     URL <- "https://gitlab.com/ibarraespinosa/veinextras/-/raw/master/amazonas2014.tar.gz"
     tf <- paste0(tempfile(), ".tar.gz")
@@ -193,6 +214,25 @@ get_project <- function(directory,
     utils::untar(tarfile = tf, exdir = directory)
     message("Your directory is in ", directory)
 
+    # eu_bu_chem ####
+  } else if(case %in% c("eu_bu_chem")){
+    URL <- "https://gitlab.com/ibarraespinosa/veinextras/-/raw/master/eu_bu_chem.tar.gz"
+    tf <- paste0(tempfile(), ".tar.gz")
+    utils::download.file(url = URL,
+                         destfile =  tf)
+    utils::untar(tarfile = tf, exdir = directory)
+    message("Your directory for vehicular emissions is in ", directory)
+
+    # eu_bu_chem_simple ####
+  } else if(case %in% c("eu_bu_chem_simple")){
+    URL <- "https://gitlab.com/ibarraespinosa/veinextras/-/raw/master/eu_bu_chem_simple.tar.gz"
+    tf <- paste0(tempfile(), ".tar.gz")
+    utils::download.file(url = URL,
+                         destfile =  tf)
+    utils::untar(tarfile = tf, exdir = directory)
+    message("Your directory for vehicular emissions is in ", directory)
+
+    # curitiba ####
   } else if(case %in% c("curitiba")){
     URL <- "https://gitlab.com/ibarraespinosa/veinextras/-/raw/master/curitiba_all/curitiba.tar.gz"
     tf <- paste0(tempfile(), ".tar.gz")
@@ -242,6 +282,8 @@ get_project <- function(directory,
    utils::untar(tarfile = paste0(directory, "/sebr_cb05co2_wrfi.tar.gz"), exdir = directory)
 
    message("Your directory is in ", directory) #nocov end
+
+   # sebr_cb05co2_im ####
     } else if(case %in% c("sebr_cb05co2_im")){
       dir.create(directory)
       tf <- paste0(tempfile(), ".tar.gz")
